(function() {
    var minZoom = 33; // percentage of screen size

    function createZoomOverlay(src) {
        var overlay = document.createElement('div');
        overlay.classList.add('zoom-overlay');
        overlay.style.position = 'fixed';
        overlay.style.left = 0;
        overlay.style.right = 0;
        overlay.style.top = 0;
        overlay.style.bottom = 0;
        overlay.style.backgroundColor = 'rgba(0, 0, 0, 0.8)';
        overlay.style.zIndex = 10000;
        overlay.style.display = 'flex';
        overlay.style.alignItems = 'center';
        overlay.style.justifyContent = 'center';
        overlay.style.opacity = 0;
        overlay.style.transition = 'opacity 0.3s ease';

        var img = document.createElement('img');
        img.src = src;
        img.style.maxWidth = '90%';
        img.style.maxHeight = '90%';
        img.style.minWidth = minZoom + '%';
        img.style.border = '5px solid white';
        img.style.borderRadius = '4px';
        img.style.boxShadow = '0 0 10px rgba(0, 0, 0, 0.3)';
        overlay.appendChild(img);

        overlay.addEventListener('click', function() {
            overlay.style.opacity = 0;
            setTimeout(function() {
                document.body.removeChild(overlay);
            }, 300);
        });

        return overlay;
    }

    function replaceZoomClickHandlers() {
        var zoomButtons = document.querySelectorAll('.affiliate-zoom-container .zoom-button');
        zoomButtons.forEach(function(button) {
            button.addEventListener('click', function(e) {
                e.preventDefault();
                e.stopPropagation();

                var container = button.closest('.affiliate-zoom-container');
                var img = container.querySelector('img');
                var src = img ? (img.dataset.src || img.src) : null;

                console.log('Zoom button clicked');
                console.log('Container:', container);
                console.log('Image element:', img);
                console.log('Image source:', src);

                if (img && src) {
                    var overlay = createZoomOverlay(src);
                    document.body.appendChild(overlay);
                    setTimeout(function() {
                        overlay.style.opacity = 1;
                    }, 50);
                } else {
                    console.warn('No image found for zoom');
                }
            });
        });
    }

    document.addEventListener('DOMContentLoaded', function() {
        console.log('DOM content loaded, replacing zoom click handlers');
        replaceZoomClickHandlers();
    });
})();
